#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Find the minimum path length between 2 smarts patterns
# or the path length between 2 named atoms
#############################################################################
from __future__ import print_function
import sys
from openeye import oechem


def AtomPathLength(ifs, ofs, itf, atm1, atm2):
    for mol in ifs.GetOEGraphMols():
        oechem.OETriposAtomNames(mol)

        a1 = None
        a2 = None
        for atm in mol.GetAtoms():
            if atm.GetName() == atm1:
                a1 = atm
            if atm.GetName() == atm2:
                a2 = atm
            if a1 is not None and a2 is not None:
                break

        if a1 is None or a2 is None:
            oechem.OEThrow.Warning("Failed to find atoms %s and %s in molecule" % (atm1, atm2))
            continue

        pathlen = oechem.OEGetPathLength(a1, a2)
        if itf.GetBool("-verbose") or not itf.HasString("-o"):
            print("Path length: %s in %s" % (pathlen, oechem.OEMolToSmiles(mol)))

        spath = oechem.OEShortestPath(a1, a2)
        spathmol = oechem.OEGraphMol()
        adjustHCount = True
        oechem.OESubsetMol(spathmol, mol, oechem.OEIsAtomMember(spath), adjustHCount)
        spathsmiles = oechem.OEMolToSmiles(spathmol)

        if itf.HasString("-o"):
            oechem.OEWriteMolecule(ofs, spathmol)
        elif itf.GetBool("-verbose"):
            print(spathsmiles)


def SmartsPathLength(ifs, ofs, itf, ss1, ss2):
    for mol in ifs.GetOEGraphMols():
        oechem.OEPrepareSearch(mol, ss1)
        oechem.OEPrepareSearch(mol, ss2)
        if not (ss1.SingleMatch(mol) and ss2.SingleMatch(mol)):
            oechem.OEThrow.Warning("Unable to find SMARTS matches in %s, skipping" % mol.GetTitle())
            continue

        unique = True
        allminlen = sys.maxsize
        for match1 in ss1.Match(mol, unique):
            for match2 in ss2.Match(mol, unique):
                minlen = sys.maxsize
                for atom1 in match1.GetTargetAtoms():
                    for atom2 in match2.GetTargetAtoms():
                        pathlen = oechem.OEGetPathLength(atom1, atom2)
                        if minlen > pathlen:
                            minlen = pathlen
                            atompairs = []
                            atompairs.append([atom1, atom2])

                        elif minlen == pathlen:
                            atompairs.append([atom1, atom2])

                if minlen < allminlen:
                    allminlen = minlen
                    allatompairs = atompairs[:]

                elif minlen == allminlen:
                    allatompairs += atompairs[:]

        if itf.GetBool("-verbose") or not itf.HasString("-o"):
            print("Shortest path length: %s in %s" % (allminlen, oechem.OEMolToSmiles(mol)))

        spathlist = set()
        for satom1, satom2, in allatompairs:
            spath = oechem.OEShortestPath(satom1, satom2)
            spathmol = oechem.OEGraphMol()
            oechem.OESubsetMol(spathmol, mol, oechem.OEIsAtomMember(spath))
            spathsmiles = oechem.OEMolToSmiles(spathmol)

            if spathsmiles in spathlist:
                continue
            spathlist.add(spathsmiles)

            if itf.HasString("-o"):
                oechem.OEWriteMolecule(ofs, spathmol)
            elif itf.GetBool("-verbose"):
                print(spathsmiles)

    return


def main(argv=[__name__]):
    itf = oechem.OEInterface(Interface, argv)

    if not ((itf.HasString("-smarts1") and itf.HasString("-smarts2")) ^
            (itf.HasString("-atom1") and itf.HasString("-atom2"))):
        oechem.OEThrow.Fatal("-smarts1 and -smarts2 or -atom1 and -atom2 must be set")

    ifs = oechem.oemolistream()
    if not ifs.open(itf.GetString("-i")):
        oechem.OEThrow.Fatal("Unable to open %s for reading" %
                             itf.GetString("-i").rstrip())

    ofs = oechem.oemolostream()
    if itf.HasString("-o"):
        if not ofs.open(itf.GetString("-o")):
            oechem.OEThrow.Fatal("Unable to open %s for writing" % itf.GetString("-o"))

    if itf.HasString("-smarts1") and itf.HasString("-smarts2"):
        ss1 = oechem.OESubSearch()
        smarts1 = itf.GetString("-smarts1")
        if not ss1.Init(smarts1):
            oechem.OEThrow.Fatal("Unable to parse SMARTS1: %s" % smarts1.rstrip())

        ss2 = oechem.OESubSearch()
        smarts2 = itf.GetString("-smarts2")
        if not ss2.Init(smarts2):
            oechem.OEThrow.Fatal("Unable to parse SMARTS2: %s" % smarts2.rstrip())

        SmartsPathLength(ifs, ofs, itf, ss1, ss2)

    else:
        atom1 = itf.GetString("-atom1")
        atom2 = itf.GetString("-atom2")
        AtomPathLength(ifs, ofs, itf, atom1, atom2)


Interface = """
!BRIEF -i <input> [-o <output>] -smarts1 <smarts> -smarts2 <smarts> | -atom1 <name> -atom2 <name>
!PARAMETER -i
  !TYPE string
  !REQUIRED true
  !BRIEF Input file name
  !KEYLESS 1
!END
!PARAMETER -o
  !TYPE string
  !REQUIRED false
  !BRIEF Output file name
  !KEYLESS 2
!END
!PARAMETER -smarts1
  !TYPE string
  !BRIEF Smarts pattern to identify 1st atom
!END
!PARAMETER -smarts2
  !TYPE string
  !BRIEF Smarts pattern to identify 2nd atom
!END
!PARAMETER -atom1
  !TYPE string
  !BRIEF Name of 1st atom
!END
!PARAMETER -atom2
  !TYPE string
  !BRIEF Name of 2nd atom
!END
!PARAMETER -verbose
  !TYPE bool
  !REQUIRED false
  !DEFAULT false
  !BRIEF Print verbose output
!END
"""


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict


# @ <SNIPPET-IMAGE-FRAME>
def DrawMolecule(image, mol, width, height, offset):

    frame = oedepict.OEImageFrame(image, width, height, offset)

    oedepict.OEDrawBorder(frame, oedepict.OELightGreyPen)

    opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
    disp = oedepict.OE2DMolDisplay(mol, opts)

    clearbackground = True
    oedepict.OERenderMolecule(frame, disp, not clearbackground)


image = oedepict.OEImage(400, 400)

mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "C1CC(O)CNC1")
oedepict.OEPrepareDepiction(mol)

DrawMolecule(image, mol, 60, 60, oedepict.OE2DPoint(50.0, 40.0))
DrawMolecule(image, mol, 180, 180, oedepict.OE2DPoint(180.0, 120.0))
DrawMolecule(image, mol, 80, 80, oedepict.OE2DPoint(300.0, 20.0))
DrawMolecule(image, mol, 50, 50, oedepict.OE2DPoint(150.0, 320.0))
DrawMolecule(image, mol, 20, 20, oedepict.OE2DPoint(360.0, 360.0))

oedepict.OEWriteImage("ImageFrame.png", image)
# @ </SNIPPET-IMAGE-FRAME>
oedepict.OEWriteImage("ImageFrame.pdf", image)



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info

def swig_import_helper():
    from os.path import dirname
    import imp
    fp = None
    try:
        fp, pathname, description = imp.find_module('_oechem', [dirname(__file__)])
    except ImportError:
        # OpenEye Import Statements
        fp, pathname, description = imp.find_module('libs', [dirname(__file__)])
        try:
            libs = imp.load_module('libs', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()

        import sys
        assert not sys.platform.startswith('win')
        
        _oeiupac = libs.OEGetModule('_oeiupac266')
        return _oeiupac

_oeiupac = swig_import_helper()
del swig_import_helper
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        object.__setattr__(self, name, value)
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0



def _swig_setattr_nondynamic_method(set):
    def set_attr(self, name, value):
        if (name == "thisown"):
            return self.this.own(value)
        if hasattr(self, name) or (name == "this"):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


try:
    import weakref
    weakref_proxy = weakref.proxy
except Exception:
    weakref_proxy = lambda x: x


class OEUCharArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEUCharArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEUCharArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEUCharArray') -> "bool":
        return _oeiupac.OEUCharArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEUCharArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEUCharArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEUCharArray___repr__(self)

    def PtrCast(self, *args) -> "unsigned char const *":
        return _oeiupac.OEUCharArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEUCharArray___len__(self)
OEUCharArray_swigregister = _oeiupac.OEUCharArray_swigregister
OEUCharArray_swigregister(OEUCharArray)

class OEUIntArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEUIntArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEUIntArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEUIntArray') -> "bool":
        return _oeiupac.OEUIntArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEUIntArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEUIntArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEUIntArray___repr__(self)

    def PtrCast(self, *args) -> "unsigned int const *":
        return _oeiupac.OEUIntArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEUIntArray___len__(self)
OEUIntArray_swigregister = _oeiupac.OEUIntArray_swigregister
OEUIntArray_swigregister(OEUIntArray)

class OEIntArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEIntArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEIntArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEIntArray') -> "bool":
        return _oeiupac.OEIntArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEIntArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEIntArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEIntArray___repr__(self)

    def PtrCast(self, *args) -> "int const *":
        return _oeiupac.OEIntArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEIntArray___len__(self)
OEIntArray_swigregister = _oeiupac.OEIntArray_swigregister
OEIntArray_swigregister(OEIntArray)

class OEFloatArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEFloatArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEFloatArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEFloatArray') -> "bool":
        return _oeiupac.OEFloatArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEFloatArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEFloatArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEFloatArray___repr__(self)

    def PtrCast(self, *args) -> "float const *":
        return _oeiupac.OEFloatArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEFloatArray___len__(self)
OEFloatArray_swigregister = _oeiupac.OEFloatArray_swigregister
OEFloatArray_swigregister(OEFloatArray)

class OEDoubleArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEDoubleArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEDoubleArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEDoubleArray') -> "bool":
        return _oeiupac.OEDoubleArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEDoubleArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEDoubleArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEDoubleArray___repr__(self)

    def PtrCast(self, *args) -> "double const *":
        return _oeiupac.OEDoubleArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEDoubleArray___len__(self)
OEDoubleArray_swigregister = _oeiupac.OEDoubleArray_swigregister
OEDoubleArray_swigregister(OEDoubleArray)

class OEBoolArray(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __swig_destroy__ = _oeiupac.delete_OEBoolArray
    __del__ = lambda self: None

    def __init__(self, *args):
        this = _oeiupac.new_OEBoolArray(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __eq__(self, other: 'OEBoolArray') -> "bool":
        return _oeiupac.OEBoolArray___eq__(self, other)

    def __setitem__(self, *args) -> "void":
        return _oeiupac.OEBoolArray___setitem__(self, *args)

    def __getitem__(self, obj):
        if not isinstance(obj, slice):
            return _oeiupac.OEBoolArray___getitem__(self, obj)

        indices = range(*obj.indices(len(self)))
        newarr  = self.__class__(len(indices))
        for dst, src in enumerate(indices):
            newarr[dst] = self[src]
        return newarr



    def __repr__(self) -> "PyObject *":
        return _oeiupac.OEBoolArray___repr__(self)

    def PtrCast(self, *args) -> "bool const *":
        return _oeiupac.OEBoolArray_PtrCast(self, *args)

    def __len__(self) -> "Py_ssize_t":
        return _oeiupac.OEBoolArray___len__(self)
OEBoolArray_swigregister = _oeiupac.OEBoolArray_swigregister
OEBoolArray_swigregister(OEBoolArray)

class OEUIntVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OEUIntVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OEUIntVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OEUIntVector_clear(self)

    def append(self, x: 'unsigned int') -> "void":
        return _oeiupac.OEUIntVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OEUIntVector___nonzero__(self)

    def pop(self) -> "unsigned int":
        return _oeiupac.OEUIntVector_pop(self)

    def __getitem__(self, i: 'int') -> "unsigned int":
        return _oeiupac.OEUIntVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< unsigned int >":
        return _oeiupac.OEUIntVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'unsigned int') -> "void":
        return _oeiupac.OEUIntVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OEUIntVector') -> "void":
        return _oeiupac.OEUIntVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OEUIntVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OEUIntVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OEUIntVector
    __del__ = lambda self: None
OEUIntVector_swigregister = _oeiupac.OEUIntVector_swigregister
OEUIntVector_swigregister(OEUIntVector)

class OEIntVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OEIntVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OEIntVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OEIntVector_clear(self)

    def append(self, x: 'int') -> "void":
        return _oeiupac.OEIntVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OEIntVector___nonzero__(self)

    def pop(self) -> "int":
        return _oeiupac.OEIntVector_pop(self)

    def __getitem__(self, i: 'int') -> "int":
        return _oeiupac.OEIntVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< int >":
        return _oeiupac.OEIntVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'int') -> "void":
        return _oeiupac.OEIntVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OEIntVector') -> "void":
        return _oeiupac.OEIntVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OEIntVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OEIntVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OEIntVector
    __del__ = lambda self: None
OEIntVector_swigregister = _oeiupac.OEIntVector_swigregister
OEIntVector_swigregister(OEIntVector)

class OELongVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OELongVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OELongVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OELongVector_clear(self)

    def append(self, x: 'long') -> "void":
        return _oeiupac.OELongVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OELongVector___nonzero__(self)

    def pop(self) -> "long":
        return _oeiupac.OELongVector_pop(self)

    def __getitem__(self, i: 'int') -> "long":
        return _oeiupac.OELongVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< long >":
        return _oeiupac.OELongVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'long') -> "void":
        return _oeiupac.OELongVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OELongVector') -> "void":
        return _oeiupac.OELongVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OELongVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OELongVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OELongVector
    __del__ = lambda self: None
OELongVector_swigregister = _oeiupac.OELongVector_swigregister
OELongVector_swigregister(OELongVector)

class OECharVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OECharVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OECharVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OECharVector_clear(self)

    def append(self, x: 'char') -> "void":
        return _oeiupac.OECharVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OECharVector___nonzero__(self)

    def pop(self) -> "char":
        return _oeiupac.OECharVector_pop(self)

    def __getitem__(self, i: 'int') -> "char":
        return _oeiupac.OECharVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< char >":
        return _oeiupac.OECharVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'char') -> "void":
        return _oeiupac.OECharVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OECharVector') -> "void":
        return _oeiupac.OECharVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OECharVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OECharVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OECharVector
    __del__ = lambda self: None
OECharVector_swigregister = _oeiupac.OECharVector_swigregister
OECharVector_swigregister(OECharVector)

class OEUCharVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OEUCharVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OEUCharVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OEUCharVector_clear(self)

    def append(self, x: 'unsigned char') -> "void":
        return _oeiupac.OEUCharVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OEUCharVector___nonzero__(self)

    def pop(self) -> "unsigned char":
        return _oeiupac.OEUCharVector_pop(self)

    def __getitem__(self, i: 'int') -> "unsigned char":
        return _oeiupac.OEUCharVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< unsigned char >":
        return _oeiupac.OEUCharVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'unsigned char') -> "void":
        return _oeiupac.OEUCharVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OEUCharVector') -> "void":
        return _oeiupac.OEUCharVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OEUCharVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OEUCharVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OEUCharVector
    __del__ = lambda self: None
OEUCharVector_swigregister = _oeiupac.OEUCharVector_swigregister
OEUCharVector_swigregister(OEUCharVector)

class OEFloatVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OEFloatVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OEFloatVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OEFloatVector_clear(self)

    def append(self, x: 'float') -> "void":
        return _oeiupac.OEFloatVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OEFloatVector___nonzero__(self)

    def pop(self) -> "float":
        return _oeiupac.OEFloatVector_pop(self)

    def __getitem__(self, i: 'int') -> "float":
        return _oeiupac.OEFloatVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< float >":
        return _oeiupac.OEFloatVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'float') -> "void":
        return _oeiupac.OEFloatVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OEFloatVector') -> "void":
        return _oeiupac.OEFloatVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OEFloatVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OEFloatVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OEFloatVector
    __del__ = lambda self: None
OEFloatVector_swigregister = _oeiupac.OEFloatVector_swigregister
OEFloatVector_swigregister(OEFloatVector)

class OEDoubleVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oeiupac.new_OEDoubleVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oeiupac.OEDoubleVector___len__(self)

    def clear(self) -> "void":
        return _oeiupac.OEDoubleVector_clear(self)

    def append(self, x: 'double') -> "void":
        return _oeiupac.OEDoubleVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oeiupac.OEDoubleVector___nonzero__(self)

    def pop(self) -> "double":
        return _oeiupac.OEDoubleVector_pop(self)

    def __getitem__(self, i: 'int') -> "double":
        return _oeiupac.OEDoubleVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< double >":
        return _oeiupac.OEDoubleVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'double') -> "void":
        return _oeiupac.OEDoubleVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'OEDoubleVector') -> "void":
        return _oeiupac.OEDoubleVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oeiupac.OEDoubleVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oeiupac.OEDoubleVector___delslice__(self, i, j)
    __swig_destroy__ = _oeiupac.delete_OEDoubleVector
    __del__ = lambda self: None
OEDoubleVector_swigregister = _oeiupac.OEDoubleVector_swigregister
OEDoubleVector_swigregister(OEDoubleVector)


def __no_op(*args) -> "void":
    return _oeiupac.__no_op(*args)
__no_op = _oeiupac.__no_op
import openeye.oechem as oechem

_oeiupac.OENamStyle_NS_VERSION_swigconstant(_oeiupac)
OENamStyle_NS_VERSION = _oeiupac.OENamStyle_NS_VERSION

_oeiupac.OENamStyle_NS_COMMON_swigconstant(_oeiupac)
OENamStyle_NS_COMMON = _oeiupac.OENamStyle_NS_COMMON

_oeiupac.OENamStyle_NS_CAS_swigconstant(_oeiupac)
OENamStyle_NS_CAS = _oeiupac.OENamStyle_NS_CAS

_oeiupac.OENamStyle_NS_OLD_swigconstant(_oeiupac)
OENamStyle_NS_OLD = _oeiupac.OENamStyle_NS_OLD

_oeiupac.OENamStyle_NS_SYS_swigconstant(_oeiupac)
OENamStyle_NS_SYS = _oeiupac.OENamStyle_NS_SYS

_oeiupac.OENamStyle_NS_ESTER_swigconstant(_oeiupac)
OENamStyle_NS_ESTER = _oeiupac.OENamStyle_NS_ESTER

_oeiupac.OENamStyle_NS_STEREO_swigconstant(_oeiupac)
OENamStyle_NS_STEREO = _oeiupac.OENamStyle_NS_STEREO

_oeiupac.OENamStyle_NS_DASH_swigconstant(_oeiupac)
OENamStyle_NS_DASH = _oeiupac.OENamStyle_NS_DASH

_oeiupac.OENamStyle_NS_AMINE_swigconstant(_oeiupac)
OENamStyle_NS_AMINE = _oeiupac.OENamStyle_NS_AMINE

_oeiupac.OENamStyle_NS_RINGLOC_swigconstant(_oeiupac)
OENamStyle_NS_RINGLOC = _oeiupac.OENamStyle_NS_RINGLOC

_oeiupac.OENamStyle_NS_PERMIDX_swigconstant(_oeiupac)
OENamStyle_NS_PERMIDX = _oeiupac.OENamStyle_NS_PERMIDX

_oeiupac.OENamStyle_NS_IUPAC79_swigconstant(_oeiupac)
OENamStyle_NS_IUPAC79 = _oeiupac.OENamStyle_NS_IUPAC79

_oeiupac.OENamStyle_NS_IUPAC93_swigconstant(_oeiupac)
OENamStyle_NS_IUPAC93 = _oeiupac.OENamStyle_NS_IUPAC93

_oeiupac.OENamStyle_NS_AUTONOM_swigconstant(_oeiupac)
OENamStyle_NS_AUTONOM = _oeiupac.OENamStyle_NS_AUTONOM

_oeiupac.OENamStyle_NS_PSEUDOHAL_swigconstant(_oeiupac)
OENamStyle_NS_PSEUDOHAL = _oeiupac.OENamStyle_NS_PSEUDOHAL

_oeiupac.OENamStyle_NS_ACDNAME_swigconstant(_oeiupac)
OENamStyle_NS_ACDNAME = _oeiupac.OENamStyle_NS_ACDNAME

_oeiupac.OENamStyle_NS_AMMONIO_swigconstant(_oeiupac)
OENamStyle_NS_AMMONIO = _oeiupac.OENamStyle_NS_AMMONIO

_oeiupac.OENamStyle_NS_PERMIDX2_swigconstant(_oeiupac)
OENamStyle_NS_PERMIDX2 = _oeiupac.OENamStyle_NS_PERMIDX2

_oeiupac.OENamStyle_NS_1NLOC_swigconstant(_oeiupac)
OENamStyle_NS_1NLOC = _oeiupac.OENamStyle_NS_1NLOC

_oeiupac.OENamStyle_NS_FLIPENH_swigconstant(_oeiupac)
OENamStyle_NS_FLIPENH = _oeiupac.OENamStyle_NS_FLIPENH

_oeiupac.OENamStyle_NS_MAX_swigconstant(_oeiupac)
OENamStyle_NS_MAX = _oeiupac.OENamStyle_NS_MAX

_oeiupac.OECharSet_DEFAULT_swigconstant(_oeiupac)
OECharSet_DEFAULT = _oeiupac.OECharSet_DEFAULT

_oeiupac.OECharSet_ASCII_swigconstant(_oeiupac)
OECharSet_ASCII = _oeiupac.OECharSet_ASCII

_oeiupac.OECharSet_HTML_swigconstant(_oeiupac)
OECharSet_HTML = _oeiupac.OECharSet_HTML

_oeiupac.OECharSet_UTF8_swigconstant(_oeiupac)
OECharSet_UTF8 = _oeiupac.OECharSet_UTF8

_oeiupac.OECharSet_SJIS_swigconstant(_oeiupac)
OECharSet_SJIS = _oeiupac.OECharSet_SJIS

_oeiupac.OECharSet_EUCJP_swigconstant(_oeiupac)
OECharSet_EUCJP = _oeiupac.OECharSet_EUCJP

_oeiupac.OECharSet_Latin1_swigconstant(_oeiupac)
OECharSet_Latin1 = _oeiupac.OECharSet_Latin1

_oeiupac.OELanguage_ENGLISH_swigconstant(_oeiupac)
OELanguage_ENGLISH = _oeiupac.OELanguage_ENGLISH

_oeiupac.OELanguage_AMERICAN_swigconstant(_oeiupac)
OELanguage_AMERICAN = _oeiupac.OELanguage_AMERICAN

_oeiupac.OELanguage_BRITISH_swigconstant(_oeiupac)
OELanguage_BRITISH = _oeiupac.OELanguage_BRITISH

_oeiupac.OELanguage_INTERNATIONAL_swigconstant(_oeiupac)
OELanguage_INTERNATIONAL = _oeiupac.OELanguage_INTERNATIONAL

_oeiupac.OELanguage_CHINESE_swigconstant(_oeiupac)
OELanguage_CHINESE = _oeiupac.OELanguage_CHINESE

_oeiupac.OELanguage_DANISH_swigconstant(_oeiupac)
OELanguage_DANISH = _oeiupac.OELanguage_DANISH

_oeiupac.OELanguage_DUTCH_swigconstant(_oeiupac)
OELanguage_DUTCH = _oeiupac.OELanguage_DUTCH

_oeiupac.OELanguage_FRENCH_swigconstant(_oeiupac)
OELanguage_FRENCH = _oeiupac.OELanguage_FRENCH

_oeiupac.OELanguage_GERMAN_swigconstant(_oeiupac)
OELanguage_GERMAN = _oeiupac.OELanguage_GERMAN

_oeiupac.OELanguage_GREEK_swigconstant(_oeiupac)
OELanguage_GREEK = _oeiupac.OELanguage_GREEK

_oeiupac.OELanguage_HUNGARIAN_swigconstant(_oeiupac)
OELanguage_HUNGARIAN = _oeiupac.OELanguage_HUNGARIAN

_oeiupac.OELanguage_IRISH_swigconstant(_oeiupac)
OELanguage_IRISH = _oeiupac.OELanguage_IRISH

_oeiupac.OELanguage_ITALIAN_swigconstant(_oeiupac)
OELanguage_ITALIAN = _oeiupac.OELanguage_ITALIAN

_oeiupac.OELanguage_JAPANESE_swigconstant(_oeiupac)
OELanguage_JAPANESE = _oeiupac.OELanguage_JAPANESE

_oeiupac.OELanguage_POLISH_swigconstant(_oeiupac)
OELanguage_POLISH = _oeiupac.OELanguage_POLISH

_oeiupac.OELanguage_PORTUGUESE_swigconstant(_oeiupac)
OELanguage_PORTUGUESE = _oeiupac.OELanguage_PORTUGUESE

_oeiupac.OELanguage_ROMANIAN_swigconstant(_oeiupac)
OELanguage_ROMANIAN = _oeiupac.OELanguage_ROMANIAN

_oeiupac.OELanguage_RUSSIAN_swigconstant(_oeiupac)
OELanguage_RUSSIAN = _oeiupac.OELanguage_RUSSIAN

_oeiupac.OELanguage_SLOVAK_swigconstant(_oeiupac)
OELanguage_SLOVAK = _oeiupac.OELanguage_SLOVAK

_oeiupac.OELanguage_SPANISH_swigconstant(_oeiupac)
OELanguage_SPANISH = _oeiupac.OELanguage_SPANISH

_oeiupac.OELanguage_SWEDISH_swigconstant(_oeiupac)
OELanguage_SWEDISH = _oeiupac.OELanguage_SWEDISH

_oeiupac.OELanguage_WELSH_swigconstant(_oeiupac)
OELanguage_WELSH = _oeiupac.OELanguage_WELSH

def OENameLocant(loc: 'unsigned int', iupac: 'bool'=False) -> "std::string":
    """
    OENameLocant(unsigned int loc, bool iupac=False) -> std::string
    OENameLocant(unsigned int loc) -> std::string
    """
    return _oeiupac.OENameLocant(loc, iupac)

def OEParseIUPACName(mol: 'OEMolBase', name: 'char const *') -> "bool":
    """OEParseIUPACName(OEMolBase mol, char const * name) -> bool"""
    return _oeiupac.OEParseIUPACName(mol, name)

def OECreateIUPACName(*args) -> "std::string":
    """
    OECreateIUPACName(OEMolBase mol, unsigned char const * style) -> std::string
    OECreateIUPACName(OEMolBase mol) -> std::string
    """
    return _oeiupac.OECreateIUPACName(*args)

def OEGetIUPACNamStyle(style: 'std::string const &') -> "unsigned char const *":
    """OEGetIUPACNamStyle(std::string const & style) -> unsigned char const *"""
    return _oeiupac.OEGetIUPACNamStyle(style)

def OEGetCIPStereo(*args) -> "char":
    """
    OEGetCIPStereo(OEMolBase mol, OEAtomBase atm) -> char
    OEGetCIPStereo(OEMolBase mol, OEBondBase bnd) -> char
    """
    return _oeiupac.OEGetCIPStereo(*args)

def OESetCIPStereo(*args) -> "bool":
    """
    OESetCIPStereo(OEMolBase mol, OEAtomBase atm, char s) -> bool
    OESetCIPStereo(OEMolBase mol, OEBondBase bnd, char s) -> bool
    """
    return _oeiupac.OESetCIPStereo(*args)

def OECapitalizeName(ptr: 'char const *') -> "std::string":
    """OECapitalizeName(char const * ptr) -> std::string"""
    return _oeiupac.OECapitalizeName(ptr)

def OELowerCaseName(ptr: 'char const *') -> "std::string":
    """OELowerCaseName(char const * ptr) -> std::string"""
    return _oeiupac.OELowerCaseName(ptr)

def OEReorderIndexName(ptr: 'char const *') -> "std::string":
    """OEReorderIndexName(char const * ptr) -> std::string"""
    return _oeiupac.OEReorderIndexName(ptr)

def OEGetIUPACLanguage(langStr: 'std::string const &') -> "unsigned int":
    """OEGetIUPACLanguage(std::string const & langStr) -> unsigned int"""
    return _oeiupac.OEGetIUPACLanguage(langStr)

def OEFromLanguage(ptr: 'char const *', lang: 'unsigned int') -> "std::string":
    """OEFromLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEFromLanguage(ptr, lang)

def OEToLanguage(ptr: 'char const *', lang: 'unsigned int') -> "std::string":
    """OEToLanguage(char const * ptr, unsigned int lang) -> std::string"""
    return _oeiupac.OEToLanguage(ptr, lang)

def OEToBritish(ptr: 'char const *', sulph: 'bool') -> "std::string":
    """OEToBritish(char const * ptr, bool sulph) -> std::string"""
    return _oeiupac.OEToBritish(ptr, sulph)

def OEToChinese(ptr: 'char const *') -> "std::string":
    """OEToChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEToChinese(ptr)

def OEToDanish(ptr: 'char const *') -> "std::string":
    """OEToDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToDanish(ptr)

def OEToDutch(ptr: 'char const *') -> "std::string":
    """OEToDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEToDutch(ptr)

def OEToFrench(ptr: 'char const *') -> "std::string":
    """OEToFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEToFrench(ptr)

def OEToGerman(ptr: 'char const *') -> "std::string":
    """OEToGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEToGerman(ptr)

def OEToGreek(ptr: 'char const *') -> "std::string":
    """OEToGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEToGreek(ptr)

def OEToHungarian(ptr: 'char const *') -> "std::string":
    """OEToHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEToHungarian(ptr)

def OEToIrish(ptr: 'char const *') -> "std::string":
    """OEToIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEToIrish(ptr)

def OEToItalian(ptr: 'char const *') -> "std::string":
    """OEToItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEToItalian(ptr)

def OEToJapanese(ptr: 'char const *') -> "std::string":
    """OEToJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEToJapanese(ptr)

def OEToPolish(ptr: 'char const *') -> "std::string":
    """OEToPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEToPolish(ptr)

def OEToPortuguese(ptr: 'char const *') -> "std::string":
    """OEToPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEToPortuguese(ptr)

def OEToRomanian(ptr: 'char const *') -> "std::string":
    """OEToRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRomanian(ptr)

def OEToRussian(ptr: 'char const *') -> "std::string":
    """OEToRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEToRussian(ptr)

def OEToSlovak(ptr: 'char const *') -> "std::string":
    """OEToSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEToSlovak(ptr)

def OEToSpanish(ptr: 'char const *') -> "std::string":
    """OEToSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSpanish(ptr)

def OEToSwedish(ptr: 'char const *') -> "std::string":
    """OEToSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEToSwedish(ptr)

def OEToWelsh(ptr: 'char const *') -> "std::string":
    """OEToWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEToWelsh(ptr)

def OEFromBritish(ptr: 'char const *') -> "std::string":
    """OEFromBritish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromBritish(ptr)

def OEFromChinese(ptr: 'char const *') -> "std::string":
    """OEFromChinese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromChinese(ptr)

def OEFromDanish(ptr: 'char const *') -> "std::string":
    """OEFromDanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDanish(ptr)

def OEFromDutch(ptr: 'char const *') -> "std::string":
    """OEFromDutch(char const * ptr) -> std::string"""
    return _oeiupac.OEFromDutch(ptr)

def OEFromFrench(ptr: 'char const *') -> "std::string":
    """OEFromFrench(char const * ptr) -> std::string"""
    return _oeiupac.OEFromFrench(ptr)

def OEFromGerman(ptr: 'char const *') -> "std::string":
    """OEFromGerman(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGerman(ptr)

def OEFromGreek(ptr: 'char const *') -> "std::string":
    """OEFromGreek(char const * ptr) -> std::string"""
    return _oeiupac.OEFromGreek(ptr)

def OEFromHungarian(ptr: 'char const *') -> "std::string":
    """OEFromHungarian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHungarian(ptr)

def OEFromIrish(ptr: 'char const *') -> "std::string":
    """OEFromIrish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromIrish(ptr)

def OEFromItalian(ptr: 'char const *') -> "std::string":
    """OEFromItalian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromItalian(ptr)

def OEFromJapanese(ptr: 'char const *') -> "std::string":
    """OEFromJapanese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromJapanese(ptr)

def OEFromPolish(ptr: 'char const *') -> "std::string":
    """OEFromPolish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPolish(ptr)

def OEFromPortuguese(ptr: 'char const *') -> "std::string":
    """OEFromPortuguese(char const * ptr) -> std::string"""
    return _oeiupac.OEFromPortuguese(ptr)

def OEFromRomanian(ptr: 'char const *') -> "std::string":
    """OEFromRomanian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRomanian(ptr)

def OEFromRussian(ptr: 'char const *') -> "std::string":
    """OEFromRussian(char const * ptr) -> std::string"""
    return _oeiupac.OEFromRussian(ptr)

def OEFromSlovak(ptr: 'char const *') -> "std::string":
    """OEFromSlovak(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSlovak(ptr)

def OEFromSpanish(ptr: 'char const *') -> "std::string":
    """OEFromSpanish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSpanish(ptr)

def OEFromSwedish(ptr: 'char const *') -> "std::string":
    """OEFromSwedish(char const * ptr) -> std::string"""
    return _oeiupac.OEFromSwedish(ptr)

def OEFromWelsh(ptr: 'char const *') -> "std::string":
    """OEFromWelsh(char const * ptr) -> std::string"""
    return _oeiupac.OEFromWelsh(ptr)

def OEGetIUPACCharSet(charset: 'std::string const &') -> "unsigned int":
    """OEGetIUPACCharSet(std::string const & charset) -> unsigned int"""
    return _oeiupac.OEGetIUPACCharSet(charset)

def OEToASCII(ptr: 'char const *', remove_markup: 'bool const'=True) -> "std::string":
    """
    OEToASCII(char const * ptr, bool const remove_markup=True) -> std::string
    OEToASCII(char const * ptr) -> std::string
    """
    return _oeiupac.OEToASCII(ptr, remove_markup)

def OEToUTF8(ptr: 'char const *', remove_markup: 'bool const'=True) -> "std::string":
    """
    OEToUTF8(char const * ptr, bool const remove_markup=True) -> std::string
    OEToUTF8(char const * ptr) -> std::string
    """
    return _oeiupac.OEToUTF8(ptr, remove_markup)

def OEFromUTF8(ptr: 'char const *') -> "std::string":
    """OEFromUTF8(char const * ptr) -> std::string"""
    return _oeiupac.OEFromUTF8(ptr)

def OEToHTML(ptr: 'char const *') -> "std::string":
    """OEToHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEToHTML(ptr)

def OEFromHTML(ptr: 'char const *') -> "std::string":
    """OEFromHTML(char const * ptr) -> std::string"""
    return _oeiupac.OEFromHTML(ptr)

def OEToSJIS(ptr: 'char const *') -> "std::string":
    """OEToSJIS(char const * ptr) -> std::string"""
    return _oeiupac.OEToSJIS(ptr)

def OEToEUCJP(ptr: 'char const *') -> "std::string":
    """OEToEUCJP(char const * ptr) -> std::string"""
    return _oeiupac.OEToEUCJP(ptr)

def OEFromKOI8R(ptr: 'char const *') -> "std::string":
    """OEFromKOI8R(char const * ptr) -> std::string"""
    return _oeiupac.OEFromKOI8R(ptr)

_oeiupac.OE_OEIUPAC_VERSION_swigconstant(_oeiupac)
OE_OEIUPAC_VERSION = _oeiupac.OE_OEIUPAC_VERSION

def OEIUPACGetRelease() -> "char const *":
    """OEIUPACGetRelease() -> char const *"""
    return _oeiupac.OEIUPACGetRelease()

def OEIUPACGetVersion() -> "unsigned int":
    """OEIUPACGetVersion() -> unsigned int"""
    return _oeiupac.OEIUPACGetVersion()

def OEIUPACGetArch() -> "char const *":
    """OEIUPACGetArch() -> char const *"""
    return _oeiupac.OEIUPACGetArch()

def OEIUPACGetPlatform() -> "char const *":
    """OEIUPACGetPlatform() -> char const *"""
    return _oeiupac.OEIUPACGetPlatform()

def OEIUPACIsLicensed(feature: 'char const *'=None, expdate: 'unsigned int *'=None) -> "bool":
    """
    OEIUPACIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool
    OEIUPACIsLicensed(char const * feature=None) -> bool
    OEIUPACIsLicensed() -> bool
    """
    return _oeiupac.OEIUPACIsLicensed(feature, expdate)

def OEIUPACGetLicensee(*args) -> "std::string":
    """
    OEIUPACGetLicensee(std::string & licensee) -> bool
    OEIUPACGetLicensee() -> std::string
    """
    return _oeiupac.OEIUPACGetLicensee(*args)

def OEIUPACGetSite(*args) -> "std::string":
    """
    OEIUPACGetSite(std::string & site) -> bool
    OEIUPACGetSite() -> std::string
    """
    return _oeiupac.OEIUPACGetSite(*args)

cvar = _oeiupac.cvar
OENamStyleOpenEye = cvar.OENamStyleOpenEye
OENamStyleTraditional = cvar.OENamStyleTraditional
OENamStyleSystematic = cvar.OENamStyleSystematic
OENamStyleIUPAC = cvar.OENamStyleIUPAC
OENamStyleCAS = cvar.OENamStyleCAS
OENamStyleCASIndex = cvar.OENamStyleCASIndex
OENamStyleAutoNom = cvar.OENamStyleAutoNom
OENamStyleIUPAC79 = cvar.OENamStyleIUPAC79
OENamStyleIUPAC93 = cvar.OENamStyleIUPAC93
OENamStyleACDName = cvar.OENamStyleACDName




#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import os
import sys
import argparse

from openeye import oechem
from openeye import oefastrocs

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


def main(argv=[__name__]):

    parser = argparse.ArgumentParser()

    # positional arguments retaining backward compatibility
    parser.add_argument('database',
                        help='File containing the database molecules to be search (format not restricted to *.oeb).')
    parser.add_argument('query', default=[], nargs='+',
                        help='File containing the query molecule(s) to be search (format not restricted to *.oeb).')
    parser.add_argument('--nHits', dest='nHits', type=int, default=100,
                        help='Number of hits to return (default = number of database mols).')
    parser.add_argument('--cutoff',  dest='cutoff', type=float, default=argparse.SUPPRESS,
                        help='Specify a cutoff criteria for scores.')
    parser.add_argument('--tversky', dest='tversky', action='store_true', default=argparse.SUPPRESS,
                        help='Switch to Tversky similarity scoring (default = Tanimoto).')

    args = parser.parse_args()

    dbname = args.database

    if not oefastrocs.OEFastROCSIsGPUReady():
        oechem.OEThrow.Info("No supported GPU available!")
        return 0

    # set options
    opts = oefastrocs.OEShapeDatabaseOptions()
    opts.SetLimit(args.nHits)
    print("Number of hits set to %u" % opts.GetLimit())
    if hasattr(args, 'cutoff') is not False:
        opts.SetCutoff(args.cutoff)
        print("Cutoff set to %f" % args.cutoff)
    if hasattr(args, 'tversky') is not False:
        opts.SetSimFunc(args.tversky)
        print("Tversky similarity scoring set.")

    # read in database
    ifs = oechem.oemolistream()
    if not ifs.open(dbname):
        oechem.OEThrow.Fatal("Unable to open '%s'" % dbname)

    print("\nOpening database file %s ..." % dbname)
    timer = oechem.OEWallTimer()
    dbase = oefastrocs.OEShapeDatabase()
    moldb = oechem.OEMolDatabase()
    if not moldb.Open(ifs):
        oechem.OEThrow.Fatal("Unable to open '%s'" % dbname)

    dots = oechem.OEThreadedDots(10000, 200, "conformers")
    if not dbase.Open(moldb, dots):
        oechem.OEThrow.Fatal("Unable to initialize OEShapeDatabase on '%s'" % dbname)

    dots.Total()
    print("%f seconds to load database\n" % timer.Elapsed())

    for qfname in args.query:

        # read in query
        qfs = oechem.oemolistream()
        if not qfs.open(qfname):
            oechem.OEThrow.Fatal("Unable to open '%s'" % qfname)

        mcmol = oechem.OEMol()
        if not oechem.OEReadMolecule(qfs, mcmol):
            oechem.OEThrow.Fatal("Unable to read query from '%s'" % qfname)
        qfs.rewind()

        ext = oechem.OEGetFileExtension(qfname)

        qmolidx = 0
        while oechem.OEReadMolecule(qfs, mcmol):

            # write out to file name based on molecule title
            ofs = oechem.oemolostream()
            moltitle = mcmol.GetTitle()
            if len(moltitle) == 0:
                moltitle = str(qmolidx)
            ofname = moltitle + "_results." + ext
            if not ofs.open(ofname):
                oechem.OEThrow.Fatal("Unable to open '%s'" % argv[4])

            print("Searching for %s of %s (%s conformers)" % (moltitle, qfname, mcmol.NumConfs()))

            qconfidx = 0
            for conf in mcmol.GetConfs():

                for score in dbase.GetSortedScores(conf, opts):

                    dbmol = oechem.OEMol()
                    dbmolidx = score.GetMolIdx()
                    if not moldb.GetMolecule(dbmol, dbmolidx):
                        print("Unable to retrieve molecule '%u' from the database" % dbmolidx)
                        continue

                    mol = oechem.OEGraphMol(dbmol.GetConf(oechem.OEHasConfIdx(score.GetConfIdx())))

                    oechem.OESetSDData(mol, "QueryConfidx", "%s" % qconfidx)
                    oechem.OESetSDData(mol, "ShapeTanimoto", "%.4f" % score.GetShapeTanimoto())
                    oechem.OESetSDData(mol, "ColorTanimoto", "%.4f" % score.GetColorTanimoto())
                    oechem.OESetSDData(mol, "TanimotoCombo", "%.4f" % score.GetTanimotoCombo())
                    score.Transform(mol)

                    oechem.OEWriteMolecule(ofs, mol)

                qconfidx += 1

            print("%s conformers processed" % qconfidx)
            print("Wrote results to %s\n" % ofname)

        qmolidx += 1
    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


# @ <SNIPPET-OEADDLABEL-PREDICATE>
def OEAddLabel_Predicate(disp):
    ringhighlight = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, ringhighlight, oechem.OEAtomIsInRing(), oechem.OEBondIsInRing())
    ringlabel = oedepict.OEHighlightLabel("ring", oechem.OELightGreen)
    oedepict.OEAddLabel(disp, ringlabel, oechem.OEAtomIsInRing())

    chainhighlight = oedepict.OEHighlightByBallAndStick(oechem.OEBlueTint)
    oedepict.OEAddHighlighting(disp, chainhighlight, oechem.OEAtomIsInChain(), oechem.OEBondIsInChain())
    chainlabel = oedepict.OEHighlightLabel("chain", oechem.OEBlueTint)
    oedepict.OEAddLabel(disp, chainlabel, oechem.OEAtomIsInChain())
# @ </SNIPPET-OEADDLABEL-PREDICATE>


# @ <SNIPPET-OEADDLABEL-OEMATCH>
def OEAddLabel_OEMatch(disp):
    subs = oechem.OESubSearch("a1aaaaa1")
    unique = True
    highlightstyle = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    for match in subs.Match(disp.GetMolecule(), unique):
        oedepict.OEAddHighlighting(disp, highlightstyle, match)
        label = oedepict.OEHighlightLabel("aromatic", oechem.OELightGreen)
        oedepict.OEAddLabel(disp, label, match)
# @ </SNIPPET-OEADDLABEL-OEMATCH>


# @ <SNIPPET-OEADDLABEL-OEATOMBONDSET>
def OEAddLabel_OEAtomBondSet(disp):
    mol = disp.GetMolecule()

    ringset = oechem.OEAtomBondSet(mol.GetAtoms(oechem.OEAtomIsInRing()), mol.GetBonds(oechem.OEBondIsInRing()))
    ringhighlight = oedepict.OEHighlightByBallAndStick(oechem.OELightGreen)
    oedepict.OEAddHighlighting(disp, ringhighlight, ringset)
    ringlabel = oedepict.OEHighlightLabel("ring", oechem.OELightGreen)
    oedepict.OEAddLabel(disp, ringlabel, ringset)

    chainset = oechem.OEAtomBondSet(mol.GetAtoms(oechem.OEAtomIsInChain()), mol.GetBonds(oechem.OEBondIsInChain()))
    chainhighlight = oedepict.OEHighlightByBallAndStick(oechem.OEBlueTint)
    oedepict.OEAddHighlighting(disp, chainhighlight, chainset)
    chainlabel = oedepict.OEHighlightLabel("chain", oechem.OEBlueTint)
    oedepict.OEAddLabel(disp, chainlabel, chainset)
# @ </SNIPPET-OEADDLABEL-OEATOMBONDSET>


# @ <SNIPPET-OEADDLABEL-TO-IMAGE>
def OEAddLabel_OEImage(image):

    label = oedepict.OEHighlightLabel("Hello!")
    oedepict.OEAddLabel(image, oedepict.OE2DPoint(50, 50), label)

    label.SetBoundingBoxPen(oedepict.OETransparentPen)
    oedepict.OEAddLabel(image, oedepict.OE2DPoint(100, 50), label)

    label.SetBoundingBoxPen(oedepict.OELightGreyPen)
    oedepict.OEAddLabel(image, oedepict.OE2DPoint(150, 50), label)
# @ </SNIPPET-OEADDLABEL-TO-IMAGE>

########################################################################
#
########################################################################


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "CC(=O)C1Cc2ccccc2N1")
oedepict.OEPrepareDepiction(mol)

width, height = 250, 180
opts = oedepict.OE2DMolDisplayOptions(width, height, oedepict.OEScale_AutoScale)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddLabel_Predicate(disp)
oedepict.OERenderMolecule("OEAddLabel-Predicate.png", disp)
oedepict.OERenderMolecule("OEAddLabel-Predicate.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddLabel_OEMatch(disp)
oedepict.OERenderMolecule("OEAddLabel-OEMatch.png", disp)
oedepict.OERenderMolecule("OEAddLabel-OEMatch.pdf", disp)

disp = oedepict.OE2DMolDisplay(mol, opts)
OEAddLabel_OEAtomBondSet(disp)
oedepict.OERenderMolecule("OEAddLabel-OEAtomBondSet.png", disp)
oedepict.OERenderMolecule("OEAddLabel-OEAtomBondSet.pdf", disp)

image = oedepict.OEImage(200, 100)
OEAddLabel_OEImage(image)
oedepict.OEWriteImage("OEAddLabel-OEImageBase.png", image)
oedepict.OEWriteImage("OEAddLabel-OEImageBase.pdf", image)



# CONFIDENTIAL. (C) 2017 OpenEye Scientific Software Inc.
# All rights reserved.
# 
# ALL SOFTWARE BELOW IS PROPRIETARY AND CONFIDENTIAL TO OPENEYE
# SCIENTIFIC SOFTWARE INC., AND IS SUBJECT TO THE FULL PROTECTION OF
# COPYRIGHT AND TRADESECRET LAW.
# Copying or modifying this software is strictly prohibited and illegal.
# Using this software without a valid license from OpenEye is strictly
# prohibited and illegal.  De-obfuscating, de-minimizing, or any other
# attempt to reverse engineer or discover the workings of this software,
# is strictly prohibited. Even if software is exposed or visible, it is
# still proprietary and confidential and the above prohibitions apply.
# This software is NOT "Sample Code". For purposes of customization or
# interoperation with other software you must use Sample Code
# specifically labeled as such.
# Please contact OpenEye at eyesopen.com/legal if you have any questions
# about this warning.


# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.8
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.





from sys import version_info

def swig_import_helper():
    from os.path import dirname
    import imp
    fp = None
    try:
        fp, pathname, description = imp.find_module('_oechem', [dirname(__file__)])
    except ImportError:
        # OpenEye Import Statements
        fp, pathname, description = imp.find_module('libs', [dirname(__file__)])
        try:
            libs = imp.load_module('libs', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()

        import sys
        assert not sys.platform.startswith('win')
        
        _oespruce = libs.OEGetModule('_oespruce091')
        return _oespruce

_oespruce = swig_import_helper()
del swig_import_helper
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        object.__setattr__(self, name, value)
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0



def _swig_setattr_nondynamic_method(set):
    def set_attr(self, name, value):
        if (name == "thisown"):
            return self.this.own(value)
        if hasattr(self, name) or (name == "this"):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


try:
    import weakref
    weakref_proxy = weakref.proxy
except Exception:
    weakref_proxy = lambda x: x


class StringVector(object):
    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _oespruce.new_StringVector(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def __len__(self) -> "unsigned int":
        return _oespruce.StringVector___len__(self)

    def clear(self) -> "void":
        return _oespruce.StringVector_clear(self)

    def append(self, x: 'std::string') -> "void":
        return _oespruce.StringVector_append(self, x)

    def __nonzero__(self) -> "bool":
        return _oespruce.StringVector___nonzero__(self)

    def pop(self) -> "std::string":
        return _oespruce.StringVector_pop(self)

    def __getitem__(self, i: 'int') -> "std::string":
        return _oespruce.StringVector___getitem__(self, i)

    def __getslice__(self, i: 'int', j: 'int') -> "std::vector< std::string >":
        return _oespruce.StringVector___getslice__(self, i, j)

    def __setitem__(self, i: 'int', x: 'std::string') -> "void":
        return _oespruce.StringVector___setitem__(self, i, x)

    def __setslice__(self, i: 'int', j: 'int', v: 'StringVector') -> "void":
        return _oespruce.StringVector___setslice__(self, i, j, v)

    def __delitem__(self, i: 'int') -> "void":
        return _oespruce.StringVector___delitem__(self, i)

    def __delslice__(self, i: 'int', j: 'int') -> "void":
        return _oespruce.StringVector___delslice__(self, i, j)
    __swig_destroy__ = _oespruce.delete_StringVector
    __del__ = lambda self: None
StringVector_swigregister = _oespruce.StringVector_swigregister
StringVector_swigregister(StringVector)

import openeye.oechem as oechem

_oespruce.OESuperpositionType_Undefined_swigconstant(_oespruce)
OESuperpositionType_Undefined = _oespruce.OESuperpositionType_Undefined

_oespruce.OESuperpositionType_Global_swigconstant(_oespruce)
OESuperpositionType_Global = _oespruce.OESuperpositionType_Global

_oespruce.OESuperpositionType_Site_swigconstant(_oespruce)
OESuperpositionType_Site = _oespruce.OESuperpositionType_Site

_oespruce.OESuperpositionType_DDM_swigconstant(_oespruce)
OESuperpositionType_DDM = _oespruce.OESuperpositionType_DDM

_oespruce.OESuperpositionType_Weighted_swigconstant(_oespruce)
OESuperpositionType_Weighted = _oespruce.OESuperpositionType_Weighted

_oespruce.OESuperpositionType_SSE_swigconstant(_oespruce)
OESuperpositionType_SSE = _oespruce.OESuperpositionType_SSE

OESuperpositionType_Default = OESuperpositionType_Global


_oespruce.OESuperpositionType_Max_swigconstant(_oespruce)
OESuperpositionType_Max = _oespruce.OESuperpositionType_Max
class OEOptions(object):
    """Proxy of C++ OESystem::OEOptions class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr
    __swig_destroy__ = _oespruce.delete_OEOptions
    __del__ = lambda self: None

    def Validate(self) -> "bool":
        """Validate(OEOptions self) -> bool"""
        return _oespruce.OEOptions_Validate(self)

OEOptions_swigregister = _oespruce.OEOptions_swigregister
OEOptions_swigregister(OEOptions)

class OESuperpositionOptions(object):
    """Proxy of C++ OESpruce::OESuperpositionOptions class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        """
        __init__(OESpruce::OESuperpositionOptions self) -> OESuperpositionOptions
        __init__(OESpruce::OESuperpositionOptions self, OESuperpositionOptions rhs) -> OESuperpositionOptions
        """
        this = _oespruce.new_OESuperpositionOptions(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _oespruce.delete_OESuperpositionOptions
    __del__ = lambda self: None

    def SetSuperpositionType(self, type: 'unsigned int') -> "bool":
        """SetSuperpositionType(OESuperpositionOptions self, unsigned int type) -> bool"""
        return _oespruce.OESuperpositionOptions_SetSuperpositionType(self, type)


    def GetSuperpositionType(self) -> "unsigned int":
        """GetSuperpositionType(OESuperpositionOptions self) -> unsigned int"""
        return _oespruce.OESuperpositionOptions_GetSuperpositionType(self)


    def AddSiteResidue(self, argSiteResidue: 'std::string const &') -> "void":
        """AddSiteResidue(OESuperpositionOptions self, std::string const & argSiteResidue)"""
        return _oespruce.OESuperpositionOptions_AddSiteResidue(self, argSiteResidue)


    def ClearSiteResidues(self) -> "void":
        """ClearSiteResidues(OESuperpositionOptions self)"""
        return _oespruce.OESuperpositionOptions_ClearSiteResidues(self)


    def SetDist(self, argDist: 'double') -> "void":
        """SetDist(OESuperpositionOptions self, double argDist)"""
        return _oespruce.OESuperpositionOptions_SetDist(self, argDist)


    def GetDist(self) -> "double":
        """GetDist(OESuperpositionOptions self) -> double"""
        return _oespruce.OESuperpositionOptions_GetDist(self)


    def SetLigandConstraints(self, refLig: 'OEMolBase', fitLig: 'OEMolBase') -> "void":
        """SetLigandConstraints(OESuperpositionOptions self, OEMolBase refLig, OEMolBase fitLig)"""
        return _oespruce.OESuperpositionOptions_SetLigandConstraints(self, refLig, fitLig)


    def GetLigandConstraints(self, refLig: 'OEMolBase', fitLig: 'OEMolBase') -> "void":
        """GetLigandConstraints(OESuperpositionOptions self, OEMolBase refLig, OEMolBase fitLig)"""
        return _oespruce.OESuperpositionOptions_GetLigandConstraints(self, refLig, fitLig)


    def ClearLigandConstraints(self) -> "void":
        """ClearLigandConstraints(OESuperpositionOptions self)"""
        return _oespruce.OESuperpositionOptions_ClearLigandConstraints(self)


    def HasLigandConstraints(self) -> "bool":
        """HasLigandConstraints(OESuperpositionOptions self) -> bool"""
        return _oespruce.OESuperpositionOptions_HasLigandConstraints(self)


    def SetSiteResidues(self, list: 'PyObject *') -> "void":
        """SetSiteResidues(OESuperpositionOptions self, PyObject * list)"""
        return _oespruce.OESuperpositionOptions_SetSiteResidues(self, list)


    def GetSiteResidues(self) -> "PyObject *":
        """GetSiteResidues(OESuperpositionOptions self) -> PyObject *"""
        return _oespruce.OESuperpositionOptions_GetSiteResidues(self)

OESuperpositionOptions_swigregister = _oespruce.OESuperpositionOptions_swigregister
OESuperpositionOptions_swigregister(OESuperpositionOptions)

class OEStructuralSuperposition(object):
    """Proxy of C++ OESpruce::OEStructuralSuperposition class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    __swig_destroy__ = _oespruce.delete_OEStructuralSuperposition
    __del__ = lambda self: None

    def __init__(self, *args):
        """
        __init__(OESpruce::OEStructuralSuperposition self, OEMolBase argRefMol, OEMolBase argFitMol, OESuperpositionOptions argOpts) -> OEStructuralSuperposition
        __init__(OESpruce::OEStructuralSuperposition self, OEMolBase argRefMol, OEMolBase argFitMol) -> OEStructuralSuperposition
        __init__(OESpruce::OEStructuralSuperposition self, OEStructuralSuperposition rhs) -> OEStructuralSuperposition
        """
        this = _oespruce.new_OEStructuralSuperposition(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def IsValid(self):
      return _oespruce.OEStructuralSuperposition___nonzero__(self)



    def GetRotMatrix(self, rmat: 'double *') -> "void":
        """GetRotMatrix(OEStructuralSuperposition self, double * rmat)"""
        return _oespruce.OEStructuralSuperposition_GetRotMatrix(self, rmat)


    def GetTranslation(self, trans: 'double *') -> "void":
        """GetTranslation(OEStructuralSuperposition self, double * trans)"""
        return _oespruce.OEStructuralSuperposition_GetTranslation(self, trans)


    def Transform(self, mol: 'OEMolBase') -> "void":
        """Transform(OEStructuralSuperposition self, OEMolBase mol)"""
        return _oespruce.OEStructuralSuperposition_Transform(self, mol)


    def GetRMSD(self) -> "double":
        """GetRMSD(OEStructuralSuperposition self) -> double"""
        return _oespruce.OEStructuralSuperposition_GetRMSD(self)


    def GetScore(self) -> "int":
        """GetScore(OEStructuralSuperposition self) -> int"""
        return _oespruce.OEStructuralSuperposition_GetScore(self)


    def ConstraintsMet(self) -> "bool":
        """ConstraintsMet(OEStructuralSuperposition self) -> bool"""
        return _oespruce.OEStructuralSuperposition_ConstraintsMet(self)


    def GetRefChains(self) -> "PyObject *":
        """GetRefChains(OEStructuralSuperposition self) -> PyObject *"""
        return _oespruce.OEStructuralSuperposition_GetRefChains(self)


    def GetFitChains(self) -> "PyObject *":
        """GetFitChains(OEStructuralSuperposition self) -> PyObject *"""
        return _oespruce.OEStructuralSuperposition_GetFitChains(self)


    def GetRegion(self) -> "PyObject *":
        """GetRegion(OEStructuralSuperposition self) -> PyObject *"""
        return _oespruce.OEStructuralSuperposition_GetRegion(self)

OEStructuralSuperposition_swigregister = _oespruce.OEStructuralSuperposition_swigregister
OEStructuralSuperposition_swigregister(OEStructuralSuperposition)

class OESecondaryStructureSuperposition(object):
    """Proxy of C++ OESpruce::OESecondaryStructureSuperposition class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr
    __swig_destroy__ = _oespruce.delete_OESecondaryStructureSuperposition
    __del__ = lambda self: None

    def __init__(self, *args):
        """
        __init__(OESpruce::OESecondaryStructureSuperposition self, OEMolBase refMol, OEMolBase fitMol, OESuperpositionOptions argOpts) -> OESecondaryStructureSuperposition
        __init__(OESpruce::OESecondaryStructureSuperposition self, OEMolBase refMol, OEMolBase fitMol) -> OESecondaryStructureSuperposition
        __init__(OESpruce::OESecondaryStructureSuperposition self, OESecondaryStructureSuperposition rhs) -> OESecondaryStructureSuperposition
        """
        this = _oespruce.new_OESecondaryStructureSuperposition(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this

    def IsValid(self):
      return _oespruce.OESecondaryStructureSuperposition___nonzero__(self)



    def GetRotMatrix(self, rmat: 'double *') -> "void":
        """GetRotMatrix(OESecondaryStructureSuperposition self, double * rmat)"""
        return _oespruce.OESecondaryStructureSuperposition_GetRotMatrix(self, rmat)


    def GetTranslation(self, trans: 'double *') -> "void":
        """GetTranslation(OESecondaryStructureSuperposition self, double * trans)"""
        return _oespruce.OESecondaryStructureSuperposition_GetTranslation(self, trans)


    def Transform(self, mol: 'OEMolBase') -> "void":
        """Transform(OESecondaryStructureSuperposition self, OEMolBase mol)"""
        return _oespruce.OESecondaryStructureSuperposition_Transform(self, mol)


    def GetTanimoto(self) -> "double":
        """GetTanimoto(OESecondaryStructureSuperposition self) -> double"""
        return _oespruce.OESecondaryStructureSuperposition_GetTanimoto(self)


    def GetRefChains(self) -> "PyObject *":
        """GetRefChains(OESecondaryStructureSuperposition self) -> PyObject *"""
        return _oespruce.OESecondaryStructureSuperposition_GetRefChains(self)


    def GetFitChains(self) -> "PyObject *":
        """GetFitChains(OESecondaryStructureSuperposition self) -> PyObject *"""
        return _oespruce.OESecondaryStructureSuperposition_GetFitChains(self)

OESecondaryStructureSuperposition_swigregister = _oespruce.OESecondaryStructureSuperposition_swigregister
OESecondaryStructureSuperposition_swigregister(OESecondaryStructureSuperposition)

class OEBioAssemblyFactIter(object):
    """Proxy of C++ OESystem::OEIter<(OEChem::OEMolBase)> class."""

    thisown = _swig_property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc='The membership flag')
    __repr__ = _swig_repr

    def __init__(self, *args):
        """
        __init__(OESystem::OEIter<(OEChem::OEMolBase)> self) -> OEBioAssemblyFactIter
        __init__(OESystem::OEIter<(OEChem::OEMolBase)> self, OEMolBaseIter rhs) -> OEBioAssemblyFactIter
        __init__(OESystem::OEIter<(OEChem::OEMolBase)> self, OESystem::OEIterBase< OEChem::OEMolBase > * rhs) -> OEBioAssemblyFactIter
        __init__(OESystem::OEIter<(OEChem::OEMolBase)> self, OESystem::OEIterBase< OESystem::OEIter< OEChem::OEMolBase >::NonConstA > * rhs) -> OEBioAssemblyFactIter
        """
        this = _oespruce.new_OEBioAssemblyFactIter(*args)
        try:
            self.this.append(this)
        except Exception:
            self.this = this
    __swig_destroy__ = _oespruce.delete_OEBioAssemblyFactIter
    __del__ = lambda self: None

    def Copy(self) -> "OESystem::OEIterBase< OEChem::OEMolBase > *":
        """Copy(OEBioAssemblyFactIter self) -> OESystem::OEIterBase< OEChem::OEMolBase > *"""
        return _oespruce.OEBioAssemblyFactIter_Copy(self)


    def Push(self, *args) -> "void":
        """
        Push(OEBioAssemblyFactIter self, OESystem::OEIterBase< OEChem::OEMolBase > * ib)
        Push(OEBioAssemblyFactIter self, OEMolBaseIter iter)
        """
        return _oespruce.OEBioAssemblyFactIter_Push(self, *args)


    def Sort(self, sort_criterion: 'OEBinaryMolBasePred') -> "void":
        """Sort(OEBioAssemblyFactIter self, OEBinaryMolBasePred sort_criterion)"""
        return _oespruce.OEBioAssemblyFactIter_Sort(self, sort_criterion)


    def ToFirst(self) -> "OESystem::OEIter< OEChem::OEMolBase > &":
        """ToFirst(OEBioAssemblyFactIter self) -> OEMolBaseIter"""
        return _oespruce.OEBioAssemblyFactIter_ToFirst(self)


    def ToLast(self) -> "OESystem::OEIter< OEChem::OEMolBase > &":
        """ToLast(OEBioAssemblyFactIter self) -> OEMolBaseIter"""
        return _oespruce.OEBioAssemblyFactIter_ToLast(self)


    def __ref__(self) -> "OEChem::OEMolBase &":
        """__ref__(OEBioAssemblyFactIter self) -> OEMolBase"""
        return _oespruce.OEBioAssemblyFactIter___ref__(self)


    def IsValid(self):
      return _oespruce.OEBioAssemblyFactIter___nonzero__(self)



    def __iter__(self):
        while self.IsValid():
            ret = self.Target()
            ret._itr = self
            yield ret
            self.Next()



    def next(self) -> "PyObject *":
        """next(OEBioAssemblyFactIter self) -> PyObject *"""
        return _oespruce.OEBioAssemblyFactIter_next(self)


    def Target(self) -> "OEChem::OEMolBase &":
        """Target(OEBioAssemblyFactIter self) -> OEMolBase"""
        return _oespruce.OEBioAssemblyFactIter_Target(self)


    def Next(self, *args) -> "OESystem::OEIter< OEChem::OEMolBase > &":
        """
        Next(OEBioAssemblyFactIter self) -> OEMolBaseIter
        Next(OEBioAssemblyFactIter self, int i) -> OEMolBaseIter
        """
        return _oespruce.OEBioAssemblyFactIter_Next(self, *args)


    def Prev(self, *args) -> "OESystem::OEIter< OEChem::OEMolBase > &":
        """
        Prev(OEBioAssemblyFactIter self) -> OEMolBaseIter
        Prev(OEBioAssemblyFactIter self, int i) -> OEMolBaseIter
        """
        return _oespruce.OEBioAssemblyFactIter_Prev(self, *args)

OEBioAssemblyFactIter_swigregister = _oespruce.OEBioAssemblyFactIter_swigregister
OEBioAssemblyFactIter_swigregister(OEBioAssemblyFactIter)


def OEExtractBioUnits(*args) -> "OESystem::OEIterBase< OEChem::OEMolBase > *":
    """
    OEExtractBioUnits(OEMolBase extractProtein, OEMolBase refProtein) -> OESystem::OEIterBase< OEChem::OEMolBase >
    OEExtractBioUnits(OEMolBase extractProtein, OEMolBase refProtein, int minScore, bool superpose) -> OESystem::OEIterBase< OEChem::OEMolBase >
    OEExtractBioUnits(OEMolBase extractProtein, unsigned int maxAtoms, bool preferAuthor) -> OESystem::OEIterBase< OEChem::OEMolBase >
    OEExtractBioUnits(OEMolBase extractProtein) -> OESystem::OEIterBase< OEChem::OEMolBase > *
    """
    return _oespruce.OEExtractBioUnits(*args)

_oespruce.OE_OESPRUCE_VERSION_swigconstant(_oespruce)
OE_OESPRUCE_VERSION = _oespruce.OE_OESPRUCE_VERSION

def OESpruceGetRelease() -> "char const *":
    """OESpruceGetRelease() -> char const *"""
    return _oespruce.OESpruceGetRelease()

def OESpruceGetVersion() -> "unsigned int":
    """OESpruceGetVersion() -> unsigned int"""
    return _oespruce.OESpruceGetVersion()

def OESpruceGetArch() -> "char const *":
    """OESpruceGetArch() -> char const *"""
    return _oespruce.OESpruceGetArch()

def OESpruceGetPlatform() -> "char const *":
    """OESpruceGetPlatform() -> char const *"""
    return _oespruce.OESpruceGetPlatform()

def OESpruceIsLicensed(feature: 'char const *'=None, expdate: 'unsigned int *'=None) -> "bool":
    """
    OESpruceIsLicensed(char const * feature=None, unsigned int * expdate=None) -> bool
    OESpruceIsLicensed(char const * feature=None) -> bool
    OESpruceIsLicensed() -> bool
    """
    return _oespruce.OESpruceIsLicensed(feature, expdate)

def OESpruceGetLicensee(*args) -> "std::string":
    """
    OESpruceGetLicensee(std::string & licensee) -> bool
    OESpruceGetLicensee() -> std::string
    """
    return _oespruce.OESpruceGetLicensee(*args)

def OESpruceGetSite(*args) -> "std::string":
    """
    OESpruceGetSite(std::string & site) -> bool
    OESpruceGetSite() -> std::string
    """
    return _oespruce.OESpruceGetSite(*args)





#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys

from openeye import oechem
from openeye import oedocking


def main(argv=[__name__]):
    if len(argv) != 2:
        oechem.OEThrow.Usage("%s <receptor>" % argv[0])

    receptor = oechem.OEGraphMol()
    oedocking.OEReadReceptorFile(receptor, argv[1])

    # @ <SNIPPET-RECEPTOR-EXTRA-MOLECULES-EDITING-1>
    count = 0
    newExtraMolList = []
    for extraMol in oedocking.OEReceptorGetExtraMols(receptor):
        if count == 0:
            oedocking.OEReceptorSetBoundLigand(receptor, extraMol)
        else:
            newExtraMolList.append(extraMol)
        count += 1

    oedocking.OEReceptorClearExtraMols(receptor)
    for extraMol in newExtraMolList:
        oedocking.OEReceptorAddExtraMol(receptor, extraMol)
    # @ </SNIPPET-RECEPTOR-EXTRA-MOLECULES-EDITING-1>


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Print a histogram of the occurrences of various amino acids in a protein
#############################################################################
from __future__ import print_function
import sys
from openeye import oechem


def ResHist(ifs):
    nrmol = 0
    mol = oechem.OEGraphMol()
    while oechem.OEReadMolecule(ifs, mol):
        nrmol += 1
        print("==============================")
        print("Molecule: %d Title: %s" % (nrmol, mol.GetTitle()))

        nrres = 0
        resmap = {}
        if not oechem.OEHasResidues(mol):
            oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
        hv = oechem.OEHierView(mol)
        for res in hv.GetResidues():
            nrres += 1
            name = res.GetOEResidue().GetName()
            if name in resmap:
                resmap[name] += 1
            else:
                resmap[name] = 1

    sortedres = sorted(resmap.keys())
    for name in sortedres:
        percent = 100.0*float(resmap[name])/float(nrres)
        print("%3s %3d  %4.1f %%" % (name, resmap[name], percent))


if __name__ == "__main__":
    if len(sys.argv) != 2:
        oechem.OEThrow.Usage("reshist.py <infile>")
    ifs = oechem.oemolistream()
    if not ifs.open(sys.argv[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % sys.argv[1])
    ResHist(ifs)



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


# @ <SNIPPET-ANNOTATE-PARTIAL-CHARGE>
class ColorCharge(oegrapheme.OEAtomGlyphBase):
    def __init__(self, cg):
        oegrapheme.OEAtomGlyphBase.__init__(self)
        self.colorg = cg

    def RenderGlyph(self, disp, atom):
        adisp = disp.GetAtomDisplay(atom)
        if adisp is None or not adisp.IsVisible():
            return False

        charge = atom.GetPartialCharge()
        if charge == 0.0:
            return True
        color = self.colorg.GetColorAt(charge)

        pen = oedepict.OEPen()
        pen.SetForeColor(oechem.OEColor(color))
        color.SetA(100)
        pen.SetBackColor(oechem.OEColor(color))
        pen.SetFill(oedepict.OEFill_On)
        radius = disp.GetScale() / 2.5

        layer = disp.GetLayer(oedepict.OELayerPosition_Below)
        oegrapheme.OEDrawCircle(layer, oegrapheme.OECircleStyle_Simpson, adisp.GetCoords(), radius, pen)

        return True

    def CreateCopy(self):
        return ColorCharge(self.colorg).__disown__()


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "Cc1cc(cc(c1[N+](=O)[O-])F)[N+]#C")
oechem.OEMMFFAtomTypes(mol)
oechem.OEMMFF94PartialCharges(mol)

oedepict.OEPrepareDepiction(mol)

opts = oedepict.OE2DMolDisplayOptions(350, 250, oedepict.OEScale_AutoScale)
opts.SetAtomColorStyle(oedepict.OEAtomColorStyle_WhiteMonochrome)
opts.SetTitleLocation(oedepict.OETitleLocation_Hidden)
disp = oedepict.OE2DMolDisplay(mol, opts)

coloranion = oechem.OEColorStop(-1.0, oechem.OEColor(oechem.OEDarkRed))
colorcation = oechem.OEColorStop(+1.0, oechem.OEColor(oechem.OEDarkBlue))
colorg = oechem.OELinearColorGradient(coloranion, colorcation)
colorg.AddStop(oechem.OEColorStop(0.0, oechem.OEColor(oechem.OEWhite)))

colorcharge = ColorCharge(colorg)

oegrapheme.OEAddGlyph(disp, colorcharge, oechem.OEIsTrueAtom())

oedepict.OERenderMolecule("AnnotatePartialCharge.png", disp)
# @ </SNIPPET-ANNOTATE-PARTIAL-CHARGE>
oedepict.OERenderMolecule("AnnotatePartialCharge.pdf", disp)



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import sys

from openeye import oechem
from openeye import oeszybki


def main(args):
    if len(args) != 2:
        oechem.OEThrow.Usage("%s <lig>" % args[0])

    ifs = oechem.oemolistream()
    if not ifs.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % args[1])

    lig = oechem.OEMol()
    oechem.OEReadMolecule(ifs, lig)

    szOpts = oeszybki.OESzybkiOptions()
    szOpts.GetSolventOptions().SetSolventModel(oeszybki.OESolventModel_Sheffield)
    sz = oeszybki.OESzybki(szOpts)
    eres = oeszybki.OESzybkiEnsembleResults()
    S = sz.GetEntropy(lig, eres, oeszybki.OEEntropyMethod_Analytic)

    print("Configurational entropy %10.2f" % eres.GetConfigurationalEntropy())
    print("Solvation entropy       %10.2f" % eres.GetEnsembleLigSolvEntropy())
    print("                            ======")
    print("Total solution entropy  %10.2f J/(mol K)" % S)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oeff

# //////////////////////////////////////////////////////////////////////////
# The following example demonstrates how to perform ligand optimization   //
# in the context of a protein using MMFF force field.                     //
# //////////////////////////////////////////////////////////////////////////


def GetBoundsFromMol(bounds, mol, pad):
    set = False
    c = oechem.OEDoubleArray(3)
    for atom in mol.GetAtoms():
        mol.GetCoords(atom, c)
        if not set:
            bounds[0] = bounds[3] = c[0]
            bounds[1] = bounds[4] = c[1]
            bounds[2] = bounds[5] = c[2]
            set = True
        else:
            if (c[0] < bounds[0]):
                bounds[0] = c[0]
            if (c[1] < bounds[1]):
                bounds[1] = c[1]
            if (c[2] < bounds[2]):
                bounds[2] = c[2]
            if (c[0] > bounds[3]):
                bounds[3] = c[0]
            if (c[1] > bounds[4]):
                bounds[4] = c[1]
            if (c[2] > bounds[5]):
                bounds[5] = c[2]

    bounds[0] -= pad
    bounds[1] -= pad
    bounds[2] -= pad
    bounds[3] += pad
    bounds[4] += pad
    bounds[5] += pad


def main(args):
    if len(args) != 5:
        oechem.OEThrow.Usage("%s <protein> <ligand> <bound-ligand> <output>" % args[0])

    ips = oechem.oemolistream()
    if not ips.open(args[1]):
        oechem.OEThrow.Fatal("Unable to open %s for reading protein" % args[1])

    ils = oechem.oemolistream()
    if not ils.open(args[2]):
        oechem.OEThrow.Fatal("Unable to open %s for reading ligand" % args[2])

    ibs = oechem.oemolistream()
    if not ibs.open(args[3]):
        oechem.OEThrow.Fatal("Unable to open %s for reading bound ligand" % args[3])

    ofs = oechem.oemolostream()
    if not ofs.open(args[4]):
        oechem.OEThrow.Fatal("Unable to open %s for writing" % args[4])

    # Load the protein molecule and Prepare with MMFF
    protein = oechem.OEGraphMol()
    oechem.OEReadMolecule(ips, protein)
    oechem.OEAddExplicitHydrogens(protein)
    mmff2 = oeff.OEMMFF()
    mmff = oeff.OEGenericFF(mmff2)
    mmff.PrepMol(protein)

    # Get bounds for protein ligand interaction
    bounds = oechem.OEDoubleArray(6)
    boundsMol = oechem.OEGraphMol()
    oechem.OEReadMolecule(ibs, boundsMol)
    GetBoundsFromMol(bounds, boundsMol, 5.0)

    # Create intermolecular interaction functions and add to MMFF
    params = oeff.OEMMFFParams()
    interVdw = oeff.OEMMFFInterVdwNN(protein, params, bounds)
    interCoul = oeff.OEMMFFInterCoulomb(protein, bounds, 1.0, 1.0, 0.5)
    mmff.Add(interVdw)
    mmff.Add(interCoul)

    mol = oechem.OEMol()
    while oechem.OEReadMolecule(ils, mol):
        oechem.OEAddExplicitHydrogens(mol)

        if (not mmff.PrepMol(mol)) or (not mmff.Setup(mol)):
            oechem.OEThrow.Warning("Unable to process molecule: title = '%s'" % mol.GetTitle())
            oechem.OEWriteMolecule(ofs, mol)
            continue

        vecCoords = oechem.OEDoubleArray(3*mol.NumAtoms())
        for conf in mol.GetConfs():
            oechem.OEThrow.Info("Molecule: %s Conformer: %d" % (mol.GetTitle(), conf.GetIdx()+1))
            conf.GetCoords(vecCoords)

            # Calculate energy
            energy = mmff(vecCoords)
            oechem.OEThrow.Info("Initial energy: %d kcal/mol" % energy)

            # Optimize the ligand
            optimizer = oeff.OEBFGSOpt()
            energy = optimizer(mmff, vecCoords, vecCoords)
            oechem.OEThrow.Info("Optimized energy: %d kcal/mol" % energy)
            conf.SetCoords(vecCoords)

        oechem.OEWriteMolecule(ofs, mol)

    return 0


if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from openeye import oechem
import sys

# @ <SNIPPET-SetMemPoolMode>
oechem.OESetMemPoolMode(oechem.OEMemPoolMode_SingleThreaded |
                        oechem.OEMemPoolMode_UnboundedCache)
# @ </SNIPPET-SetMemPoolMode>

ss = oechem.OESubSearch(sys.argv[1])

ifs = oechem.oemolithread(sys.argv[2])
ofs = oechem.oemolothread(sys.argv[3])

for mol in ifs.GetOEGraphMols():
    oechem.OEPrepareSearch(mol, ss)
    if ss.SingleMatch(mol):
        oechem.OEWriteMolecule(ofs, mol)
# @ </SNIPPET>



#!/opt/anaconda1anaconda2anaconda3/bin/python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from __future__ import print_function
import sys
import os

try:
    from xmlrpclib import ServerProxy, Binary
    from SimpleXMLRPCServer import SimpleXMLRPCServer, SimpleXMLRPCRequestHandler
except ImportError:  # python 3
    from xmlrpc.client import ServerProxy, Binary
    from xmlrpc.server import SimpleXMLRPCServer, SimpleXMLRPCRequestHandler

from threading import Thread
from threading import Lock
from ShapeDatabaseServer import SetupStream

from openeye import oechem

oepy = os.path.join(os.path.dirname(__file__), "..", "python")
sys.path.insert(0, os.path.realpath(oepy))


class ShapeServer:
    """ Encapsulates a single ShapeDatabase running on a remote
    server."""

    def __init__(self, servername, querydata, nhits, iformat, oformat, kwargs):
        """ Create a ShapeServer specified by servername and submit
        the querydata query for nhits. """
        self.server = ServerProxy("http://" + servername)
        self.queryidx = self.server.SubmitQuery(querydata, nhits, iformat, oformat, kwargs)

    def QueryStatus(self, blocking):
        """ Return the status of this server. """
        current, total = self.server.QueryStatus(self.queryidx, blocking)

        # only return once the tracer on the server has been initialized
        while total == 0:
            blocking = True
            current, total = self.server.QueryStatus(self.queryidx, blocking)

        return current, total

    def QueryHistogram(self):
        """ Return the histogram from this server. """
        return self.server.QueryHistogram(self.queryidx)

    def QueryResults(self):
        """ Return the results of this server. """
        return self.server.QueryResults(self.queryidx)


class ShapeServerPool:
    """ Abstract a collection of ShapeServer to appear as a single
    server."""

    def __init__(self, servernames, querymolstr, nhits, iformat, oformat, kwargs):
        """ Create a collection of ShapeServers as specified by
        servernames. Launching querymolstr on each for nhits."""
        self.nhits = nhits
        self.oformat = oformat

        thrdpool = LaunchFunctionThreadPool(ShapeServer)

        for sname in servernames:
            thrdpool.AddThread(sname, querymolstr, nhits, iformat, oformat, kwargs)

        self.shapeservers = []
        for server in thrdpool.GetResults():
            self.shapeservers.append(server)

    def QueryStatus(self, blocking):
        """ Return the status of these servers. """
        thrdpool = LaunchFunctionThreadPool(ShapeServer.QueryStatus)

        for server in self.shapeservers:
            thrdpool.AddThread(server, blocking)

        current = 0
        total = 0
        for scur, stot in thrdpool.GetResults():
            sys.stderr.write("%i/%i" % (scur, stot))
            current += scur
            total += stot

        return current, total

    def QueryHistogram(self):
        """ Return the total histogram across all servers. """
        thrdpool = LaunchFunctionThreadPool(ShapeServer.QueryHistogram)

        for server in self.shapeservers:
            thrdpool.AddThread(server)

        totalHist = None
        for hist in thrdpool.GetResults():
            if totalHist is None:
                totalHist = [0] * len(hist)

            totalHist = [lhs + rhs for lhs, rhs in zip(totalHist, hist)]

        return totalHist

    def QueryResults(self):
        """ Return the best nhits results of these servers. """
        timer = oechem.OEWallTimer()
        thrdpool = LaunchFunctionThreadPool(ShapeServer.QueryResults)

        for server in self.shapeservers:
            thrdpool.AddThread(server)

        data = []
        for oebdata in thrdpool.GetResults():
            data.append(oebdata.data)

        sys.stderr.write("%f seconds to get results back" % timer.Elapsed())

        data = b"".join(data)
        if not data:
            sys.stderr.write("Possible query error, no data returned by any of the downstream servers")
            return ""

        timer.Start()
        # read in from OEB strings
        ifs = oechem.oemolistream()
        ifs = SetupStream(ifs, self.oformat)
        if not ifs.openstring(data):
            sys.stderr.write("Unable to open OEB string from downstream server")
            return ""

        mols = [oechem.OEGraphMol(mol) for mol in ifs.GetOEGraphMols()]

        def GetScoreToCmp(mol):
            if oechem.OEHasSDData(mol, "ShapeTanimoto"):
                # sort by shape tanimoto
                if oechem.OEHasSDData(mol, "TanimotoCombo"):
                    return float(oechem.OEGetSDData(mol, "TanimotoCombo"))
                return float(oechem.OEGetSDData(mol, "ShapeTanimoto"))
            else:
                # sort by shape tversky
                if oechem.OEHasSDData(mol, "TverskyCombo"):
                    return float(oechem.OEGetSDData(mol, "TverskyCombo"))
                return float(oechem.OEGetSDData(mol, "ShapeTversky"))

        mols.sort(key=GetScoreToCmp)
        mols.reverse()

        # write back out to an OEB string
        ofs = oechem.oemolostream()
        ofs = SetupStream(ofs, self.oformat)
        ofs.openstring()

        nhits = self.nhits
        if not nhits:
            nhits = len(mols)

        for mol in mols[:nhits]:
            oechem.OEWriteMolecule(ofs, mol)

        sys.stderr.write("%f seconds to collate hitlist" % timer.Elapsed())

        return Binary(ofs.GetString())


class LaunchFunctionThread(Thread):
    """ A thread to launch a function and be able to retrieve its
    return value."""

    def __init__(self, func, *args):
        Thread.__init__(self)
        self.func = func
        self.args = args

    def run(self):
        try:
            self.result = self.func(*self.args)
        except Exception as e:
            self.exception = e

    def GetResult(self):
        if hasattr(self, "exception"):
            raise self.exception
        return self.result


class LaunchFunctionThreadPool:
    """ Given a function, launch it in several threads with a separate
    argument list for each."""

    def __init__(self, func):
        """ Start a new thread pool to execute the function func. """
        self.func = func
        self.threads = []

    def AddThread(self, *args):
        """ Create and start another thread to run func on args. """
        thrd = LaunchFunctionThread(self.func, *args)
        thrd.start()
        self.threads.append(thrd)

    def GetResults(self):
        """ Returns an iterable of the results of each thread in the
        order they were added with AddThread."""
        for thrd in self.threads:
            thrd.join()
            yield thrd.GetResult()


def ShapeServerIsLoaded(servername, blocking):
    """ Helper function to determine whether a server is in the 'loaded' state. """
    server = ServerProxy("http://" + servername)
    return server.IsLoaded(blocking)


class ShapeServerProxy:
    """ Proxy queries across multiple remote shape servers."""

    def __init__(self, servernames):
        """ Create a proxy  """
        self.servernames = servernames
        self.queryidx = 0
        self.activequeries = {}
        self.lock = Lock()

    def IsLoaded(self, blocking=False):
        """ Return whether the servers have finished loading. """
        thrdpool = LaunchFunctionThreadPool(ShapeServerIsLoaded)

        for server in self.servernames:
            thrdpool.AddThread(server, blocking)

        areloaded = True
        for result in thrdpool.GetResults():
            areloaded = areloaded and result

        return areloaded

    def SubmitQuery(self, querymolstr, nhits, iformat=".oeb", oformat=".oeb", kwargs=None):
        """ Submit a query to these shape servers. """
        if not kwargs:
            kwargs = {}
        shapeservers = ShapeServerPool(self.servernames, querymolstr, nhits, iformat, oformat, kwargs)

        self.lock.acquire()
        try:
            idx = self.queryidx
            self.queryidx += 1

            self.activequeries[idx] = shapeservers
        finally:
            self.lock.release()

        return idx

    def QueryStatus(self, queryidx, blocking=False):
        """ Return the status of the query specified by queryidx. """
        self.lock.acquire()
        try:
            shapeservers = self.activequeries[queryidx]
        finally:
            self.lock.release()

        return shapeservers.QueryStatus(blocking)

    def QueryHistogram(self, queryidx):
        """ Return the current histogram of scores specified by
        queryidx."""
        self.lock.acquire()
        try:
            shapeservers = self.activequeries[queryidx]
        finally:
            self.lock.release()

        return shapeservers.QueryHistogram()

    def QueryResults(self, queryidx):
        """ Return the results of the query specified by queryidx. """
        self.lock.acquire()
        try:
            shapeservers = self.activequeries.pop(queryidx)
        finally:
            self.lock.release()

        return shapeservers.QueryResults()


# Restrict to a particular path.
class RequestHandler(SimpleXMLRPCRequestHandler):
    rpc_paths = ('/RPC2',)


def main(argv=[__name__]):
    if len(argv) < 2:
        oechem.OEThrow.Usage("%s <server 1> <server 2> ... <server n> [portnumber=8080]" % argv[0])

    # default port number is 8080
    portnumber = 8080
    try:
        portnumber = int(argv[-1])
        servernames = argv[1:-1]
    except ValueError:
        servernames = argv[1:]

    # Create server, an empty string is used to allow connections with
    # any hostname
    server = SimpleXMLRPCServer(("", portnumber),
                                requestHandler=RequestHandler)
    server.register_introspection_functions()

    server.register_instance(ShapeServerProxy(servernames))

    try:
        # Run the server's main loop
        server.serve_forever()
    finally:
        server.server_close()

    return 0


if __name__ == '__main__':
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

#############################################################################
# Output anisotropic B factor information
#############################################################################
import sys
from openeye import oechem


def main(argv=[__name__]):
    itf = oechem.OEInterface(InterfaceData, argv)

    verbose = itf.GetBool("-verbose")
    ifname = itf.GetString("-input")

    ims = oechem.oemolistream()
    if not ims.open(ifname):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % ifname)

    ims.SetFlavor(oechem.OEFormat_PDB, oechem.OEIFlavor_PDB_Default | oechem.OEIFlavor_PDB_DATA)

    for mol in ims.GetOEMols():
        if verbose:
            if not oechem.OEHasResidues(mol):
                oechem.OEPerceiveResidues(mol, oechem.OEPreserveResInfo_All)
            for atom in mol.GetAtoms():
                res = oechem.OEAtomGetResidue(atom)

                uij = oechem.OEAnisoUij()
                if oechem.OEGetAnisou(uij, atom):
                    oechem.OEThrow.Info("%s %s%c %s%d%c %c (u11=%5d, u22=%5d, u33=%5d, u12=%5d, u13=%5d, u23=%5d)" %
                                        (mol.GetTitle(),
                                         atom.GetName(),
                                         res.GetAlternateLocation(),
                                         res.GetName(),
                                         res.GetResidueNumber(),
                                         res.GetInsertCode(),
                                         res.GetChainID(),
                                         uij.GetU11(),
                                         uij.GetU22(),
                                         uij.GetU33(),
                                         uij.GetU12(),
                                         uij.GetU13(),
                                         uij.GetU23()))
                else:
                    oechem.OEThrow.Info("%s %s%c %s%d%c %c -no-anisou-" % (mol.GetTitle(),
                                        atom.GetName(),
                                        res.GetAlternateLocation(),
                                        res.GetName(),
                                        res.GetResidueNumber(),
                                        res.GetInsertCode(),
                                        res.GetChainID()))

        oechem.OEThrow.Info("%s %d atoms with anisou data (out of %d)" % (mol.GetTitle(),
                            oechem.OECount(mol, oechem.OEHasAnisou()),
                            mol.NumAtoms()))

    return 0


InterfaceData = """\
!BRIEF [-v] [-i] <mol file>

!CATEGORY "input options"

  !PARAMETER -input
    !ALIAS -i
    !TYPE string
    !REQUIRED true
    !BRIEF input mol file name
    !KEYLESS 1
  !END
!END

!CATEGORY "options"

  !PARAMETER -verbose
    !ALIAS -v
    !TYPE bool
    !DEFAULT false
    !BRIEF verbose
  !END

!END
"""

#############################################################################
if __name__ == "__main__":
    sys.exit(main(sys.argv))



#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

from openeye import oechem
from openeye import oedepict

###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE OEDEPICT DOCUMENTATION
###############################################################


def WriteTable(tableoptions, basefilename):

    image = oedepict.OEImage(300, 200)
    table = oedepict.OEImageTable(image, tableoptions)

    for idx, cell in enumerate(table.GetHeaderCells()):
        table.DrawText(cell, "(header %d)" % (idx + 1))

    for idx, cell in enumerate(table.GetStubColumnCells()):
        table.DrawText(cell, "(stub %d)" % (idx + 1))

    onlybody = True
    for row in range(1, table.NumRows(onlybody) + 1):
        for col in range(1, table.NumColumns(onlybody) + 1):
            cell = table.GetBodyCell(row, col)
            table.DrawText(cell, "(body %d, %d)" % (row, col))

    oedepict.OEDrawBorder(image, oedepict.OELightGreyPen)
    oedepict.OEWriteImage(basefilename + ".png", image)
    oedepict.OEWriteImage(basefilename + ".pdf", image)


# @ <SNIPPET-OEIMAGETABLEOPTIONS-DEFAULT>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-DEFAULT>
WriteTable(tableopts, "OEImageTableOptions_Default")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETCOLUMNWIDTHS>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetColumnWidths([20, 10, 20, 10])
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETCOLUMNWIDTHS>
WriteTable(tableopts, "OEImageTableOptions_SetColumnWidths")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETROWHEIGHTS>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetRowHeights([10, 20, 30, 40])
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETROWHEIGHTS>
WriteTable(tableopts, "OEImageTableOptions_SetRowHeights")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETBASEFONTSIZE>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetBaseFontSize(6)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETBASEFONTSIZE>
WriteTable(tableopts, "OEImageTableOptions_SetBaseFontSize")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETCELLBORDERPEN>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
pen = oedepict.OEPen(oechem.OEBlack, oechem.OEDarkBlue, oedepict.OEFill_Off, 2.0)
tableopts.SetCellBorderPen(pen)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETCELLBORDERPEN>
WriteTable(tableopts, "OEImageTableOptions_SetCellBorderPen")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETCELLCOLOR>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
evenrow = True
tableopts.SetCellColor(oechem.OELightGrey, not evenrow)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETCELLCOLOR>
WriteTable(tableopts, "OEImageTableOptions_SetCellColor")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETCELLFONT>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
font = oedepict.OEFont(oedepict.OEFontFamily_Default, oedepict.OEFontStyle_Italic | oedepict.OEFontStyle_Bold, 8,
                       oedepict.OEAlignment_Left, oechem.OEDarkRed)
tableopts.SetCellFont(font)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETCELLFONT>
WriteTable(tableopts, "OEImageTableOptions_SetCellFont")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETHEADER>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetHeader(False)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETHEADER>
WriteTable(tableopts, "OEImageTableOptions_SetHeader")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETHEADERCOLOR>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetHeaderColor(oechem.OELightGrey)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETHEADERCOLOR>
WriteTable(tableopts, "OEImageTableOptions_SetHeaderColor")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETHEADERFONT>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
font = oedepict.OEFont(oedepict.OEFontFamily_Default, oedepict.OEFontStyle_Default, 12,
                       oedepict.OEAlignment_Right, oechem.OEPinkTint)
tableopts.SetHeaderFont(font)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETHEADERFONT>
WriteTable(tableopts, "OEImageTableOptions_SetHeaderFont")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETMARGIN>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetMargin(oedepict.OEMargin_Left, 10.0)
tableopts.SetMargin(oedepict.OEMargin_Right, 10.0)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETMARGIN>
WriteTable(tableopts, "OEImageTableOptions_SetMargin")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETMARGINS>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetMargins(10.0)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETMARGINS>
WriteTable(tableopts, "OEImageTableOptions_SetMargins")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMN>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetStubColumn(True)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMN>>
WriteTable(tableopts, "OEImageTableOptions_SetStubColumn")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMNCOLOR>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetStubColumn(True)
tableopts.SetStubColumnColor(oechem.OELightGrey)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMNCOLOR>
WriteTable(tableopts, "OEImageTableOptions_SetStubColumnColor")

# @ <SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMNFONT>
tableopts = oedepict.OEImageTableOptions(4, 4, oedepict.OEImageTableStyle_MediumBlue)
tableopts.SetStubColumn(True)
font = oedepict.OEFont(oedepict.OEFontFamily_Default, oedepict.OEFontStyle_Default, 12,
                       oedepict.OEAlignment_Right, oechem.OEPinkTint)
tableopts.SetStubColumnFont(font)
# @ </SNIPPET-OEIMAGETABLEOPTIONS-SETSTUBCOLUMNFONT>
WriteTable(tableopts, "OEImageTableOptions_SetStubColumnFont")
